@@ -1,4 +1,4 @@
-/* Mixmaster version 2.9  --  (C) 1999 - 2002 Anonymizer Inc. and others.
+/* Mixmaster version 2.9  --  (C) 1999 - 2003 Anonymizer Inc. and others.
 
    Mixmaster may be redistributed and modified under certain conditions.
    This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
@@ -6,7 +6,7 @@
    details.
 
    Socket-based mail transport services
-   $Id: mail.c,v 1.7.2.8 2002/12/16 22:38:05 rabbi Exp $ */
+   $Id: mail.c 665 2003-11-09 01:47:32Z rabbi $ */
 
 
 #include "mix3.h"
@@ -153,7 +153,17 @@ int sendmail(BUFFER *message, char *from, BUFFER *address)
     /* Step 2:  Stat the file.  Wait for ENOENT as a response. */
     for (count = 0;; count++) {
       snprintf(path, PATHMAX, "%s%cout.%lu.%u_%lu.%s,S=%lu.txt",
-	POOLDIR, DIRSEP, time(NULL), getpid(), namecounter++, hostname, head->length + message->length);
+	POOLDIR, DIRSEP, time(NULL),
+#ifdef POSIX
+	getpid(),
+#else /* end of POSIX */
+#ifdef WIN32
+    _getpid(),
+#else /* end of defined(WIN32) */
+	0,
+#endif
+#endif
+	namecounter++, hostname, head->length + message->length);
 
       if (stat(path, &statbuf) == 0)
 	errno = EEXIST;
