@@ -1,4 +1,4 @@
-/* Mixmaster version 2.9  --  (C) 1999 - 2002 Anonymizer Inc. and others.
+/* Mixmaster version 2.9  --  (C) 1999 - 2003 Anonymizer Inc. and others.
 
    Mixmaster may be redistributed and modified under certain conditions.
    This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
@@ -6,9 +6,9 @@
    details.
 
    OpenPGP data
-   $Id: pgpdata.c,v 1.11.2.5 2002/12/16 22:38:09 rabbi Exp $ */
-
+   $Id: pgpdata.c 665 2003-11-09 01:47:32Z rabbi $ */
 
+#include "mix.h"
 #include "mix3.h"
 #ifdef USE_PGP
 #include "pgp.h"
@@ -946,10 +946,13 @@ static void *params(int dsa, int bits)
       buf_append(p, b, l);
       encode(p, 64);
       f = mix_openfile(DSAPARAMS, "a");
-      fprintf(f, "%s\n%d\n", begin_param, bits);
-      buf_write(p, f);
-      fprintf(f, "%s\n", end_param);
-      fclose(f);
+      if (f != NULL) {
+	fprintf(f, "%s\n%d\n", begin_param, bits);
+	buf_write(p, f);
+	fprintf(f, "%s\n", end_param);
+	fclose(f);
+      } else
+	errlog(ERRORMSG, "Cannot open %s!\n", DSAPARAMS);
       buf_free(p);
     }
     return (k);
@@ -966,10 +969,13 @@ static void *params(int dsa, int bits)
       buf_append(p, b, l);
       encode(p, 64);
       f = mix_openfile(DHPARAMS, "a");
-      fprintf(f, "%s\n%d\n", begin_param, bits);
-      buf_write(p, f);
-      fprintf(f, "%s\n", end_param);
-      fclose(f);
+      if (f != NULL) {
+	fprintf(f, "%s\n%d\n", begin_param, bits);
+	buf_write(p, f);
+	fprintf(f, "%s\n", end_param);
+	fclose(f);
+      } else
+	errlog(ERRORMSG, "Cannot open %s!\n", DHPARAMS);
       buf_free(p);
     }
     return (d);
