@@ -1,4 +1,4 @@
-/* Mixmaster version 2.9  --  (C) 1999 - 2002 Anonymizer Inc. and others.
+/* Mixmaster version 2.9  --  (C) 1999 - 2003 Anonymizer Inc. and others.
 
    Mixmaster may be redistributed and modified under certain conditions.
    This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
@@ -6,7 +6,7 @@
    details.
 
    Send messages from pool
-   $Id: pool.c,v 1.10.2.5 2002/12/16 22:38:10 rabbi Exp $ */
+   $Id: pool.c 665 2003-11-09 01:47:32Z rabbi $ */
 
 #include "mix3.h"
 #include <stdlib.h>
@@ -19,9 +19,9 @@
 #else /* end of POSIX */
 #include <io.h>
 #endif /* else if not POSIX */
-#ifndef _MSC
+#ifndef _MSC_VER
 #include <dirent.h>
-#endif /* not _MSC */
+#endif /* not _MSC_VER */
 #include <assert.h>
 
 #ifdef USE_PCRE
@@ -359,7 +359,7 @@ int pool_read(BUFFER *pool)
   int size = 0;
 
   d = opendir(POOLDIR);
-  if (d != NULL)
+  if (d != NULL) {
     for (;;) {
       e = readdir(d);
       if (e == NULL)
@@ -372,7 +372,9 @@ int pool_read(BUFFER *pool)
 	size++;
       }
     }
-  closedir(d);
+    closedir(d);
+  } else
+    errlog(WARNING, "Error reading pool dir %s\n", POOLDIR);
   return (size);
 }
 
@@ -397,7 +399,8 @@ void pool_dosend(void)
       }
     }
     closedir(d);
-  }
+  } else
+    errlog(WARNING, "Error reading pool dir %s\n", POOLDIR);
   sendmail_end();
 }
 
