@@ -1,4 +1,4 @@
-/* Mixmaster version 2.9  --  (C) 1999 - 2002 Anonymizer Inc. and others.
+/* Mixmaster version 2.9  --  (C) 1999 - 2003 Anonymizer Inc. and others.
 
    Mixmaster may be redistributed and modified under certain conditions.
    This software is distributed on an "AS IS" basis, WITHOUT WARRANTY OF
@@ -6,7 +6,7 @@
    details.
 
    Process Mixmaster remailer messages
-   $Id: rem2.c,v 1.2.2.3 2002/12/16 22:38:11 rabbi Exp $ */
+   $Id: rem2.c 665 2003-11-09 01:47:32Z rabbi $ */
 
 
 #include "mix3.h"
@@ -20,9 +20,9 @@
 #else /* end of POSIX */
 #include <io.h>
 #endif /* else if not POSIX */
-#ifndef _MSC
+#ifndef _MSC_VER
 #include <dirent.h>
-#endif /* not _MSC */
+#endif /* not _MSC_VER */
 #include <assert.h>
 
 int mix_dearmor(BUFFER *in, BUFFER *out)
